==> sitemap-generator-7.1.2.tgz: package/lib/createCrawler.js <==
const discoverResources = require('./discoverResources');
const Crawler = require('simplecrawler');

const stringifyURL = parsed =>
  `${parsed.protocol}://${parsed.host}${parsed.uriPath}`;

module.exports = (uri, options = {}) => {
  // excluded filetypes
  const exclude = [
    'gif',
    'jpg',
    'jpeg',
    'png',
    'ico',
    'bmp',
    'ogg',
    'webp',
    'mp4',
    'webm',
    'mp3',
    'ttf',
    'woff',
    'json',
    'rss',
    'atom',
    'gz',
    'zip',
    'rar',
    '7z',
    'css',
    'js',
    'gzip',
    'exe',
    'svg',
  ].join('|');

  const extRegex = new RegExp(`\\.(${exclude})$`, 'i');

  const crawler = new Crawler(uri.href);

  // set crawler options
  // see https://github.com/cgiffard/node-simplecrawler#configuration
  crawler.initialPath = uri.pathname !== '' ? uri.pathname : '/';
  crawler.maxDepth = options.crawlerMaxDepth || 0;
  crawler.decodeResponses = true;
  crawler.respectRobotsTxt = true;
  crawler.initialProtocol = uri.protocol.replace(':', '');
  crawler.userAgent = 'Node/SitemapGenerator';

  // pass query string handling option to crawler
  crawler.stripQuerystring = options.stripQuerystring || true;

  // restrict to subpages if path is privided
  crawler.addFetchCondition(parsedUrl => {
    const initialURLRegex = new RegExp(`${uri.pathname}.*`);
    return stringifyURL(parsedUrl).match(initialURLRegex);
  });

  // file type exclusion
  crawler.addFetchCondition(parsedUrl => !parsedUrl.path.match(extRegex));

  // custom discover function
  crawler.discoverResources = discoverResources;

  return crawler;
};

==> sitemap-generator-7.2.0.tgz: package/lib/createCrawler.js <==
const Crawler = require('simplecrawler');

const discoverResources = require('./discoverResources');
const stringifyURL = require('./stringifyURL');

module.exports = (uri, options = {}) => {
  // excluded filetypes
  const exclude = [
    'gif',
    'jpg',
    'jpeg',
    'png',
    'ico',
    'bmp',
    'ogg',
    'webp',
    'mp4',
    'webm',
    'mp3',
    'ttf',
    'woff',
    'json',
    'rss',
    'atom',
    'gz',
    'zip',
    'rar',
    '7z',
    'css',
    'js',
    'gzip',
    'exe',
    'svg',
  ].join('|');

  const extRegex = new RegExp(`\\.(${exclude})$`, 'i');

  const crawler = new Crawler(uri.href);

  // set crawler options
  // see https://github.com/cgiffard/node-simplecrawler#configuration
  crawler.initialPath = uri.pathname !== '' ? uri.pathname : '/';
  crawler.maxDepth = options.crawlerMaxDepth;
  crawler.decodeResponses = true;
  crawler.respectRobotsTxt = true;
  crawler.initialProtocol = uri.protocol.replace(':', '');
  crawler.userAgent = options.userAgent;

  // pass query string handling option to crawler
  crawler.stripQuerystring = options.stripQuerystring;

  // restrict to subpages if path is privided
  crawler.addFetchCondition(parsedUrl => {
    const initialURLRegex = new RegExp(`${uri.pathname}.*`);
    return stringifyURL(parsedUrl).match(initialURLRegex);
  });

  // file type exclusion
  crawler.addFetchCondition(parsedUrl => !parsedUrl.path.match(extRegex));

  // custom discover function
  crawler.discoverResources = discoverResources;

  return crawler;
};
